# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/triggers/v1/trigger_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.serverless.triggers.v1 import trigger_pb2 as yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/triggers/v1/trigger_service.proto',
  package='yandex.cloud.serverless.triggers.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/serverless/triggers/v1/trigger_service.proto\x12#yandex.cloud.serverless.triggers.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x31yandex/cloud/serverless/triggers/v1/trigger.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"-\n\x11GetTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"e\n\x13ListTriggersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"o\n\x14ListTriggersResponse\x12>\n\x08triggers\x18\x01 \x03(\x0b\x32,.yandex.cloud.serverless.triggers.v1.Trigger\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8f\x03\n\x14\x43reateTriggerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x96\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x45\n\x04rule\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.RuleB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateTriggerMetadata\x12\x12\n\ntrigger_id\x18\x01 \x01(\t\"\xfa\x02\n\x14UpdateTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x96\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x15UpdateTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14\x44\x65leteTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x15\x44\x65leteTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x13PauseTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14PauseTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14ResumeTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x15ResumeTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x92\x01\n\x1cListTriggerOperationsRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1dListTriggerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcc\x0b\n\x0eTriggerService\x12\x97\x01\n\x03Get\x12\x36.yandex.cloud.serverless.triggers.v1.GetTriggerRequest\x1a,.yandex.cloud.serverless.triggers.v1.Trigger\"*\x82\xd3\xe4\x93\x02$\x12\"/triggers/v1/triggers/{trigger_id}\x12\x9a\x01\n\x04List\x12\x38.yandex.cloud.serverless.triggers.v1.ListTriggersRequest\x1a\x39.yandex.cloud.serverless.triggers.v1.ListTriggersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/triggers/v1/triggers\x12\xac\x01\n\x06\x43reate\x12\x39.yandex.cloud.serverless.triggers.v1.CreateTriggerRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02\x1a\"\x15/triggers/v1/triggers:\x01*\xb2\xd2* \n\x15\x43reateTriggerMetadata\x12\x07Trigger\x12\xb9\x01\n\x06Update\x12\x39.yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest\x1a!.yandex.cloud.operation.Operation\"Q\x82\xd3\xe4\x93\x02\'2\"/triggers/v1/triggers/{trigger_id}:\x01*\xb2\xd2* \n\x15UpdateTriggerMetadata\x12\x07Trigger\x12\xc4\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.serverless.triggers.v1.DeleteTriggerRequest\x1a!.yandex.cloud.operation.Operation\"\\\x82\xd3\xe4\x93\x02$*\"/triggers/v1/triggers/{trigger_id}\xb2\xd2*.\n\x15\x44\x65leteTriggerMetadata\x12\x15google.protobuf.Empty\x12\xbc\x01\n\x05Pause\x12\x38.yandex.cloud.serverless.triggers.v1.PauseTriggerRequest\x1a!.yandex.cloud.operation.Operation\"V\x82\xd3\xe4\x93\x02-\"(/triggers/v1/triggers/{trigger_id}:pause:\x01*\xb2\xd2*\x1f\n\x14PauseTriggerMetadata\x12\x07Trigger\x12\xc0\x01\n\x06Resume\x12\x39.yandex.cloud.serverless.triggers.v1.ResumeTriggerRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02.\")/triggers/v1/triggers/{trigger_id}:resume:\x01*\xb2\xd2* \n\x15ResumeTriggerMetadata\x12\x07Trigger\x12\xce\x01\n\x0eListOperations\x12\x41.yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest\x1a\x42.yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/triggers/v1/triggers/{trigger_id}/operationsB{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETTRIGGERREQUEST = _descriptor.Descriptor(
  name='GetTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.GetTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.GetTriggerRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=363,
)


_LISTTRIGGERSREQUEST = _descriptor.Descriptor(
  name='ListTriggersRequest',
  full_name='yandex.cloud.serverless.triggers.v1.ListTriggersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=466,
)


_LISTTRIGGERSRESPONSE = _descriptor.Descriptor(
  name='ListTriggersResponse',
  full_name='yandex.cloud.serverless.triggers.v1.ListTriggersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='triggers', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersResponse.triggers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.triggers.v1.ListTriggersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=579,
)


_CREATETRIGGERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=981,
)

_CREATETRIGGERREQUEST = _descriptor.Descriptor(
  name='CreateTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.rule', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETRIGGERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=981,
)


_CREATETRIGGERMETADATA = _descriptor.Descriptor(
  name='CreateTriggerMetadata',
  full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.CreateTriggerMetadata.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1026,
)


_UPDATETRIGGERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=981,
)

_UPDATETRIGGERREQUEST = _descriptor.Descriptor(
  name='UpdateTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATETRIGGERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1407,
)


_UPDATETRIGGERMETADATA = _descriptor.Descriptor(
  name='UpdateTriggerMetadata',
  full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.UpdateTriggerMetadata.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1458,
)


_DELETETRIGGERREQUEST = _descriptor.Descriptor(
  name='DeleteTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.DeleteTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.DeleteTriggerRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1460,
  serialized_end=1508,
)


_DELETETRIGGERMETADATA = _descriptor.Descriptor(
  name='DeleteTriggerMetadata',
  full_name='yandex.cloud.serverless.triggers.v1.DeleteTriggerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.DeleteTriggerMetadata.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1510,
  serialized_end=1559,
)


_PAUSETRIGGERREQUEST = _descriptor.Descriptor(
  name='PauseTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.PauseTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.PauseTriggerRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=1608,
)


_PAUSETRIGGERMETADATA = _descriptor.Descriptor(
  name='PauseTriggerMetadata',
  full_name='yandex.cloud.serverless.triggers.v1.PauseTriggerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.PauseTriggerMetadata.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1658,
)


_RESUMETRIGGERREQUEST = _descriptor.Descriptor(
  name='ResumeTriggerRequest',
  full_name='yandex.cloud.serverless.triggers.v1.ResumeTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.ResumeTriggerRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1708,
)


_RESUMETRIGGERMETADATA = _descriptor.Descriptor(
  name='ResumeTriggerMetadata',
  full_name='yandex.cloud.serverless.triggers.v1.ResumeTriggerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.ResumeTriggerMetadata.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1759,
)


_LISTTRIGGEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListTriggerOperationsRequest',
  full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger_id', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest.trigger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1762,
  serialized_end=1908,
)


_LISTTRIGGEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListTriggerOperationsResponse',
  full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1910,
  serialized_end=2021,
)

_LISTTRIGGERSRESPONSE.fields_by_name['triggers'].message_type = yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2._TRIGGER
_CREATETRIGGERREQUEST_LABELSENTRY.containing_type = _CREATETRIGGERREQUEST
_CREATETRIGGERREQUEST.fields_by_name['labels'].message_type = _CREATETRIGGERREQUEST_LABELSENTRY
_CREATETRIGGERREQUEST.fields_by_name['rule'].message_type = yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2._TRIGGER_RULE
_UPDATETRIGGERREQUEST_LABELSENTRY.containing_type = _UPDATETRIGGERREQUEST
_UPDATETRIGGERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATETRIGGERREQUEST.fields_by_name['labels'].message_type = _UPDATETRIGGERREQUEST_LABELSENTRY
_LISTTRIGGEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetTriggerRequest'] = _GETTRIGGERREQUEST
DESCRIPTOR.message_types_by_name['ListTriggersRequest'] = _LISTTRIGGERSREQUEST
DESCRIPTOR.message_types_by_name['ListTriggersResponse'] = _LISTTRIGGERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateTriggerRequest'] = _CREATETRIGGERREQUEST
DESCRIPTOR.message_types_by_name['CreateTriggerMetadata'] = _CREATETRIGGERMETADATA
DESCRIPTOR.message_types_by_name['UpdateTriggerRequest'] = _UPDATETRIGGERREQUEST
DESCRIPTOR.message_types_by_name['UpdateTriggerMetadata'] = _UPDATETRIGGERMETADATA
DESCRIPTOR.message_types_by_name['DeleteTriggerRequest'] = _DELETETRIGGERREQUEST
DESCRIPTOR.message_types_by_name['DeleteTriggerMetadata'] = _DELETETRIGGERMETADATA
DESCRIPTOR.message_types_by_name['PauseTriggerRequest'] = _PAUSETRIGGERREQUEST
DESCRIPTOR.message_types_by_name['PauseTriggerMetadata'] = _PAUSETRIGGERMETADATA
DESCRIPTOR.message_types_by_name['ResumeTriggerRequest'] = _RESUMETRIGGERREQUEST
DESCRIPTOR.message_types_by_name['ResumeTriggerMetadata'] = _RESUMETRIGGERMETADATA
DESCRIPTOR.message_types_by_name['ListTriggerOperationsRequest'] = _LISTTRIGGEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListTriggerOperationsResponse'] = _LISTTRIGGEROPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTriggerRequest = _reflection.GeneratedProtocolMessageType('GetTriggerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.GetTriggerRequest)
  })
_sym_db.RegisterMessage(GetTriggerRequest)

ListTriggersRequest = _reflection.GeneratedProtocolMessageType('ListTriggersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRIGGERSREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ListTriggersRequest)
  })
_sym_db.RegisterMessage(ListTriggersRequest)

ListTriggersResponse = _reflection.GeneratedProtocolMessageType('ListTriggersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRIGGERSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ListTriggersResponse)
  })
_sym_db.RegisterMessage(ListTriggersResponse)

CreateTriggerRequest = _reflection.GeneratedProtocolMessageType('CreateTriggerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETRIGGERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.CreateTriggerRequest)
  })
_sym_db.RegisterMessage(CreateTriggerRequest)
_sym_db.RegisterMessage(CreateTriggerRequest.LabelsEntry)

CreateTriggerMetadata = _reflection.GeneratedProtocolMessageType('CreateTriggerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRIGGERMETADATA,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.CreateTriggerMetadata)
  })
_sym_db.RegisterMessage(CreateTriggerMetadata)

UpdateTriggerRequest = _reflection.GeneratedProtocolMessageType('UpdateTriggerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATETRIGGERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATETRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest)
  })
_sym_db.RegisterMessage(UpdateTriggerRequest)
_sym_db.RegisterMessage(UpdateTriggerRequest.LabelsEntry)

UpdateTriggerMetadata = _reflection.GeneratedProtocolMessageType('UpdateTriggerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRIGGERMETADATA,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.UpdateTriggerMetadata)
  })
_sym_db.RegisterMessage(UpdateTriggerMetadata)

DeleteTriggerRequest = _reflection.GeneratedProtocolMessageType('DeleteTriggerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.DeleteTriggerRequest)
  })
_sym_db.RegisterMessage(DeleteTriggerRequest)

DeleteTriggerMetadata = _reflection.GeneratedProtocolMessageType('DeleteTriggerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRIGGERMETADATA,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.DeleteTriggerMetadata)
  })
_sym_db.RegisterMessage(DeleteTriggerMetadata)

PauseTriggerRequest = _reflection.GeneratedProtocolMessageType('PauseTriggerRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSETRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.PauseTriggerRequest)
  })
_sym_db.RegisterMessage(PauseTriggerRequest)

PauseTriggerMetadata = _reflection.GeneratedProtocolMessageType('PauseTriggerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PAUSETRIGGERMETADATA,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.PauseTriggerMetadata)
  })
_sym_db.RegisterMessage(PauseTriggerMetadata)

ResumeTriggerRequest = _reflection.GeneratedProtocolMessageType('ResumeTriggerRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMETRIGGERREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ResumeTriggerRequest)
  })
_sym_db.RegisterMessage(ResumeTriggerRequest)

ResumeTriggerMetadata = _reflection.GeneratedProtocolMessageType('ResumeTriggerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESUMETRIGGERMETADATA,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ResumeTriggerMetadata)
  })
_sym_db.RegisterMessage(ResumeTriggerMetadata)

ListTriggerOperationsRequest = _reflection.GeneratedProtocolMessageType('ListTriggerOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRIGGEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest)
  })
_sym_db.RegisterMessage(ListTriggerOperationsRequest)

ListTriggerOperationsResponse = _reflection.GeneratedProtocolMessageType('ListTriggerOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRIGGEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse)
  })
_sym_db.RegisterMessage(ListTriggerOperationsResponse)


DESCRIPTOR._options = None
_GETTRIGGERREQUEST.fields_by_name['trigger_id']._options = None
_LISTTRIGGERSREQUEST.fields_by_name['folder_id']._options = None
_CREATETRIGGERREQUEST_LABELSENTRY._options = None
_CREATETRIGGERREQUEST.fields_by_name['folder_id']._options = None
_CREATETRIGGERREQUEST.fields_by_name['name']._options = None
_CREATETRIGGERREQUEST.fields_by_name['description']._options = None
_CREATETRIGGERREQUEST.fields_by_name['labels']._options = None
_CREATETRIGGERREQUEST.fields_by_name['rule']._options = None
_UPDATETRIGGERREQUEST_LABELSENTRY._options = None
_UPDATETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
_UPDATETRIGGERREQUEST.fields_by_name['name']._options = None
_UPDATETRIGGERREQUEST.fields_by_name['description']._options = None
_UPDATETRIGGERREQUEST.fields_by_name['labels']._options = None
_UPDATETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
_DELETETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
_DELETETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
_PAUSETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
_PAUSETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
_RESUMETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
_RESUMETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
_LISTTRIGGEROPERATIONSREQUEST.fields_by_name['trigger_id']._options = None
_LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTTRIGGEROPERATIONSREQUEST.fields_by_name['filter']._options = None

_TRIGGERSERVICE = _descriptor.ServiceDescriptor(
  name='TriggerService',
  full_name='yandex.cloud.serverless.triggers.v1.TriggerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2024,
  serialized_end=3508,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Get',
    index=0,
    containing_service=None,
    input_type=_GETTRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2._TRIGGER,
    serialized_options=b'\202\323\344\223\002$\022\"/triggers/v1/triggers/{trigger_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.List',
    index=1,
    containing_service=None,
    input_type=_LISTTRIGGERSREQUEST,
    output_type=_LISTTRIGGERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/triggers/v1/triggers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATETRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\032\"\025/triggers/v1/triggers:\001*\262\322* \n\025CreateTriggerMetadata\022\007Trigger',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATETRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'2\"/triggers/v1/triggers/{trigger_id}:\001*\262\322* \n\025UpdateTriggerMetadata\022\007Trigger',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETETRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$*\"/triggers/v1/triggers/{trigger_id}\262\322*.\n\025DeleteTriggerMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Pause',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Pause',
    index=5,
    containing_service=None,
    input_type=_PAUSETRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-\"(/triggers/v1/triggers/{trigger_id}:pause:\001*\262\322*\037\n\024PauseTriggerMetadata\022\007Trigger',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Resume',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.Resume',
    index=6,
    containing_service=None,
    input_type=_RESUMETRIGGERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.\")/triggers/v1/triggers/{trigger_id}:resume:\001*\262\322* \n\025ResumeTriggerMetadata\022\007Trigger',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.serverless.triggers.v1.TriggerService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTTRIGGEROPERATIONSREQUEST,
    output_type=_LISTTRIGGEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/triggers/v1/triggers/{trigger_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIGGERSERVICE)

DESCRIPTOR.services_by_name['TriggerService'] = _TRIGGERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/image.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#yandex/cloud/compute/v1/image.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xea\x03\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.compute.v1.Image.LabelsEntry\x12\x0e\n\x06\x66\x61mily\x18\x07 \x01(\t\x12\x14\n\x0cstorage_size\x18\x08 \x01(\x03\x12\x15\n\rmin_disk_size\x18\t \x01(\x03\x12\x13\n\x0bproduct_ids\x18\n \x03(\t\x12\x35\n\x06status\x18\x0b \x01(\x0e\x32%.yandex.cloud.compute.v1.Image.Status\x12\'\n\x02os\x18\x0c \x01(\x0b\x32\x1b.yandex.cloud.compute.v1.Os\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"j\n\x02Os\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .yandex.cloud.compute.v1.Os.Type\"4\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05LINUX\x10\x01\x12\x0b\n\x07WINDOWS\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_IMAGE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.Image.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=506,
  serialized_end=588,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_STATUS)

_OS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yandex.cloud.compute.v1.Os.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINUX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WINDOWS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=644,
  serialized_end=696,
)
_sym_db.RegisterEnumDescriptor(_OS_TYPE)


_IMAGE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.Image.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.Image.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.Image.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=504,
)

_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='yandex.cloud.compute.v1.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.Image.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.Image.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.compute.v1.Image.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.Image.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.Image.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.Image.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family', full_name='yandex.cloud.compute.v1.Image.family', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_size', full_name='yandex.cloud.compute.v1.Image.storage_size', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_disk_size', full_name='yandex.cloud.compute.v1.Image.min_disk_size', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_ids', full_name='yandex.cloud.compute.v1.Image.product_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.Image.status', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='yandex.cloud.compute.v1.Image.os', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMAGE_LABELSENTRY, ],
  enum_types=[
    _IMAGE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=588,
)


_OS = _descriptor.Descriptor(
  name='Os',
  full_name='yandex.cloud.compute.v1.Os',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.compute.v1.Os.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=696,
)

_IMAGE_LABELSENTRY.containing_type = _IMAGE
_IMAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_IMAGE.fields_by_name['labels'].message_type = _IMAGE_LABELSENTRY
_IMAGE.fields_by_name['status'].enum_type = _IMAGE_STATUS
_IMAGE.fields_by_name['os'].message_type = _OS
_IMAGE_STATUS.containing_type = _IMAGE
_OS.fields_by_name['type'].enum_type = _OS_TYPE
_OS_TYPE.containing_type = _OS
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['Os'] = _OS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMAGE_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.image_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.Image.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'yandex.cloud.compute.v1.image_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.Image)
  })
_sym_db.RegisterMessage(Image)
_sym_db.RegisterMessage(Image.LabelsEntry)

Os = _reflection.GeneratedProtocolMessageType('Os', (_message.Message,), {
  'DESCRIPTOR' : _OS,
  '__module__' : 'yandex.cloud.compute.v1.image_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.Os)
  })
_sym_db.RegisterMessage(Os)


DESCRIPTOR._options = None
_IMAGE_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



import time
from datetime import datetime
import logging

from google.protobuf.empty_pb2 import Empty

from yandex.cloud.operation.operation_service_pb2_grpc import OperationServiceStub
from yandex.cloud.operation.operation_service_pb2 import GetOperationRequest
from yandexcloud.operations import OperationResult, OperationError


def operation_waiter(sdk, operation_id, timeout):
    operation_service = sdk.client(OperationServiceStub)
    return OperationWaiter(operation_id, operation_service, timeout)


def wait_for_operation(sdk, operation_id, timeout):
    waiter = operation_waiter(sdk, operation_id, timeout)
    for _ in waiter:
        time.sleep(1)
    return waiter.operation


def get_operation_result(sdk, operation, response_type=None, meta_type=None, timeout=None, logger=None):
    if not logger:
        logger = logging.getLogger()
        logger.addHandler(logging.NullHandler())
    operation_result = OperationResult(operation)
    created_at = datetime.fromtimestamp(operation.created_at.seconds)
    message = 'Running Yandex.Cloud operation. ID: {id}. ' + \
              'Description: {description}. Created at: {created_at}. ' + \
              'Created by: {created_by}.'
    message = message.format(
        id=operation.id,
        description=operation.description,
        created_at=created_at,
        created_by=operation.created_by,
    )
    if meta_type and meta_type is not Empty:
        unpacked_meta = meta_type()
        operation.metadata.Unpack(unpacked_meta)
        operation_result.meta = unpacked_meta
        message += ' Meta: {unpacked_meta}.'.format(unpacked_meta=unpacked_meta)
    logger.info(message)
    result = wait_for_operation(sdk, operation.id, timeout=timeout)
    if result.error and result.error.code:
        error_message = 'Error Yandex.Cloud operation. ID: {id}. ' + \
                        'Error code: {code}. Details: {details}. ' + \
                        'Message: {message}.'
        error_message = error_message.format(
            id=result.id,
            code=result.error.code,
            details=result.error.details,
            message=result.error.message,
        )
        logger.error(error_message)
        raise OperationError(message=error_message, operation_result=result)
    else:
        log_message = 'Done Yandex.Cloud operation. ID: {id}.'.format(id=operation.id)
        if response_type and response_type is not Empty:
            unpacked_response = response_type()
            result.response.Unpack(unpacked_response)
            operation_result.response = unpacked_response
            log_message += ' Response: {unpacked_response}.'.format(unpacked_response=unpacked_response)
        logger.info(log_message)
    return operation_result


class OperationWaiter:
    def __init__(self, operation_id, operation_service, timeout=None):
        self.__operation = None
        self.__operation_id = operation_id
        self.__operation_service = operation_service
        self.__deadline = time.time() + timeout if timeout else None

    @property
    def operation(self):
        return self.__operation

    @property
    def done(self):
        self.__operation = self.__operation_service.Get(GetOperationRequest(operation_id=self.__operation_id))
        return self.__operation is not None and self.__operation.done

    def __iter__(self):
        return self

    def __next__(self):
        if self.done or self.__deadline is not None and time.time() >= self.__deadline:
            raise StopIteration()

        return None

    next = __next__  # for Python 2



import inspect

import grpc

from yandexcloud import _channels
from yandexcloud import _operation_waiter
from yandexcloud import _helpers
from yandexcloud._backoff import backoff_exponential_with_jitter
from yandexcloud._retry_interceptor import RetryInterceptor
from yandexcloud._wrappers import Wrappers


class SDK(object):
    def __init__(self, interceptor=None, **kwargs):
        self._channels = _channels.Channels(**kwargs)
        if interceptor is None:
            interceptor = RetryInterceptor(
                max_retry_count=5,
                per_call_timeout=30,
                back_off_func=backoff_exponential_with_jitter(1, 30),
            )
        self._default_interceptor = interceptor
        self.helpers = _helpers.Helpers(self)
        self.wrappers = Wrappers(self)

    def set_interceptor(self, interceptor):
        self._default_interceptor = interceptor

    def client(self, stub_ctor, interceptor=None):
        service = _service_for_ctor(stub_ctor)
        channel = self._channels.channel(service)
        if interceptor is not None:
            channel = grpc.intercept_channel(channel, interceptor)
        elif self._default_interceptor is not None:
            channel = grpc.intercept_channel(channel, self._default_interceptor)
        return stub_ctor(channel)

    def waiter(self, operation_id, timeout=None):
        return _operation_waiter.operation_waiter(self, operation_id, timeout)

    def wait_operation_and_get_result(self, operation, response_type=None, meta_type=None, timeout=None, logger=None):
        return _operation_waiter.get_operation_result(self, operation, response_type, meta_type, timeout, logger)

    def create_operation_and_get_result(
            self,
            request,
            service,
            method_name,
            response_type=None,
            meta_type=None,
            timeout=None,
            logger=None,
    ):
        operation = getattr(self.client(service), method_name)(request)
        return self.wait_operation_and_get_result(
            operation,
            response_type=response_type,
            meta_type=meta_type,
            timeout=timeout,
            logger=logger,
        )


def _service_for_ctor(stub_ctor):
    m = inspect.getmodule(stub_ctor)
    name = m.__name__
    if not name.startswith('yandex.cloud'):
        raise RuntimeError('Not a yandex.cloud service {}'.format(stub_ctor))

    for k, v in _supported_modules.items():
        if name.startswith(k):
            return v

    raise RuntimeError('Unknown service {}'.format(stub_ctor))


_supported_modules = {
    'yandex.cloud.ai.stt': 'ai-stt',
    'yandex.cloud.ai.translate': 'ai-translate',
    'yandex.cloud.ai.vision': 'ai-vision',
    'yandex.cloud.compute': 'compute',
    'yandex.cloud.containerregistry': 'container-registry',
    'yandex.cloud.dataproc.manager': 'dataproc-manager',
    'yandex.cloud.dataproc': 'dataproc',
    'yandex.cloud.endpoint': 'endpoint',
    'yandex.cloud.iam': 'iam',
    'yandex.cloud.iot.devices': 'iot-devices',
    'yandex.cloud.k8s': 'managed-kubernetes',
    'yandex.cloud.kms': 'kms',
    'yandex.cloud.loadbalancer': 'load-balancer',
    'yandex.cloud.marketplace': 'marketplace',
    'yandex.cloud.mdb.clickhouse': 'managed-clickhouse',
    'yandex.cloud.mdb.kafka': 'managed-kafka',
    'yandex.cloud.mdb.mongodb': 'managed-mongodb',
    'yandex.cloud.mdb.mysql': 'managed-mysql',
    'yandex.cloud.mdb.postgresql': 'managed-postgresql',
    'yandex.cloud.mdb.redis': 'managed-redis',
    'yandex.cloud.operation': 'operation',
    'yandex.cloud.resourcemanager': 'resource-manager',
    'yandex.cloud.serverless.functions': 'serverless-functions',
    'yandex.cloud.serverless.triggers': 'serverless-triggers',
    'yandex.cloud.vpc': 'vpc',
}
